@@ -1,12 +1,12 @@
 /*--------------------------------------------------------------------------
   ----- File:        t1lib.h
   ----- Author:      Rainer Menzner (Rainer.Menzner@web.de)
-  ----- Date:        2003-01-05
+  ----- Date:        2004-12-19
   ----- Description: This file is part of the t1-library. It must be
                      included by the user of the t1lib. It contains
 		     function declarations and some basic data types, the
 		     user must deal with.
-  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2003.
+  ----- Copyright:   t1lib is copyrighted (c) Rainer Menzner, 1996-2004.
                      As of version 0.5, t1lib is distributed under the
 		     GNU General Public Library Lincense. The
 		     conditions can be found in the files LICENSE and
@@ -38,6 +38,15 @@
 extern "C" {
 #endif
 
+/* Version information filled in by configure */
+#define T1LIB_VERSION            5
+#define T1LIB_REVISION           1
+#define T1LIB_PATCHLEVEL         0
+#define T1LIB_VERSIONSTRING      "5.1.0"
+
+/* Data Type information filled in by configure. */
+typedef short T1_int16;
+typedef int T1_int32;
 
 /* the data structure which contains the character bitmap description */
 typedef struct
@@ -183,14 +192,14 @@ extern int T1_errno;
 /* definitions for outline handling */
 #define   FRACTBITS     16   /* number of fractional bits in 'fractpel'      */
 /* From/to conversion of pels/fractpels */
-#define   T1_TOPATHPOINT(p)      (((long)p)<<FRACTBITS)
+#define   T1_TOPATHPOINT(p)      (((T1_int32)p)<<FRACTBITS)
 #define   PPHALF                 (1<<(FRACTBITS-1))
 #define   T1_NEARESTPOINT(fp)    (((fp)+PPHALF)>>FRACTBITS)
 
 /* A fractional point */
 typedef struct {
-  long x;
-  long y;
+  T1_int32 x;
+  T1_int32 y;
 } T1_PATHPOINT;
 
 
